@@ -470,12 +470,12 @@ class ANN():
         for i in range(iteration):
 
             if save_log:
-                out, error = self.forward(x, t)
-                self.backward(out, t)
+                out, error, batch_size= self.forward(x, t)
+                self.backward(out, t, batch_size)
                 self.error_log.append(error)
             else:
-                out, error = self.forward(x, t)
-                self.backward(out, t)
+                out, error, batch_size = self.forward(x, t)
+                self.backward(out, t, batch_size)
             
             #print(error)
             
@@ -549,9 +549,9 @@ class ANN():
                     print("process ==================   90%  epoch: " + str(i+1) + " error: " + str(round(error, error_round)), end="\r")
                 elif i < 10*iteration/10:
                     print("process ===================  95%  epoch: " + str(i+1) + " error: " + str(round(error, error_round)), end="\r")
-                elif i+1 == iteration:
-                    print("process ==================== 100%  epoch: " + str(i+1) + " error: " + str(round(error, error_round)), end="\n\n")
         
+        if display:
+            print("process ==================== 100%  epoch: " + str(i+1) + " error: " + str(round(error, error_round)), end="\n\n", flush=False)
         
         end_time = time.time()
         
@@ -899,8 +899,8 @@ def visualize_fanio(fan_ins, fan_outs):
     mpl.rc('axes.spines', left=False, right=False, top=False, bottom = False)
     mpl.rc('figure', titlesize = 20, figsize = (20, 7))
 
-    fig1, fi_axes = plt.subplots(1, len(fis))
-    fig2, fo_axes = plt.subplots(1, len(fos))
+    fig1, fi_axes = plt.subplots(1, len(fan_ins))
+    fig2, fo_axes = plt.subplots(1, len(fan_outs))
 
     fig1.suptitle("Actiavation Dists")
     fig2.suptitle("Fan Out Dists")
